#
# spec file for package termscp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           termscp
Version:        0.16.1
Release:        bp160.1.7
Summary:        Feature rich terminal UI file transfer and explorer
License:        MIT
URL:            https://github.com/veeso/termscp
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
# PATCH-FIX-UPSTREAM https://github.com/veeso/termscp/issues/313
Patch1:         https://github.com/veeso/termscp/commit/7dba691ccc001aa720d0ecf1642dda94219a2d21.patch
# PATCH-FIX-UPSTREAM https://github.com/veeso/termscp/issues/312
Patch2:         https://github.com/veeso/termscp/commit/099e2154bae9a954aab0569bf048c4d9ae71049e.patch
BuildRequires:  cargo >= 1.77
BuildRequires:  cargo-packaging
BuildRequires:  zstd
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(smbclient)

# error[E0063]: missing fields `bavail`, `bfree`, `blocks` and 3 other fields in initializer of `types::stat::SmbStatVfs`
#
ExcludeArch:    i586 ppc64le s390x

%description
Termscp is a feature rich terminal file transfer and explorer, with support for
SCP/SFTP/FTP/Kube/S3/WebDAV. So basically is a terminal utility with an TUI to
connect to a remote server to retrieve and upload files and to interact with
the local file system. It is Linux, MacOS, FreeBSD, NetBSD and Windows
compatible.

%prep
%autosetup -a 1 -p 1

%build
%{cargo_build}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}

%check
%{cargo_test} --features isolated-tests

%files
%{_bindir}/%{name}

%changelog
* Wed Nov 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.16.1:
  * fix: 0.16.1
  * fix: gg rust 1.82 for introducing a nice breaking change in
    config which was not mentioned in changelog
  * fix: cfg unix forbidden in rust .82
- add patches to fix build issues:
  * 099e2154bae9a954aab0569bf048c4d9ae71049e.patch
  * 7dba691ccc001aa720d0ecf1642dda94219a2d21.patch
* Tue Oct 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.16.0:
  * fix: tiny ui issue
  * fix: 0.16
  * feat: Show `..` directory before all the others in the explorer
    to navigate to the parent dir (#301)
  * fix: issue 292 New version alert was not displayed due to a
    semver regex issue. (#300)
  * fix: tuirealm 2.x (#299)
  * fix: users from lock
  * fix: vergen (#296)
  * fix: Use `uzers` instead of the dead package `users` which has
    several vulnerabilities (#295)
  * 285 feature request multi host (#293)
  * feat: version 0.16
* Fri Oct  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.15.0:
  * fix: include build.rs
  * fix: readme
  * fix: ci
  * fix: github ci is stable and reliable (one worker broken each 2
    weeks)
  * fix: set date
  * 280 feature request go to path auto completion (#287)
  * fix: `isolated-tests` feature to run tests for releasing on
    distributions which run in isolated environments (#286)
  * feat: it is now possible to cancel find command; show find
    progress (#284)
  * 249 feature request better search results (#282)
  * fix: popup texts
  * fix: issue 277 Fix a bug in the configuration page, which
    caused being stuck if the added SSH key was empty
  * fix: don't clear screen after terminating termscp
  * feat: Pods and container explorer for Kube protocol (#281)
  * fix: bump vers
  * fix: notify 6
  * fix: keyring test not passing macos
  * fix: bump vers
  * feat: init 0.15
  * fix: dbus deveL
  * fix: tokio rt builder
- drop patch dfe58e6147f66b4c0c74874c954e7d101b3bf026.patch
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- add patch dfe58e6147f66b4c0c74874c954e7d101b3bf026.patch to fix
  build errors due to tokio rt builder
  https://github.com/veeso/termscp/commit/dfe58e6147f66b4c0c74874c954e7d101b3bf026
* Fri Jul 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package termscp: feature rich terminal UI file transfer and
  explorer with support for SCP/SFTP/FTP/S3/SMB
